@@ -1582,20 +1582,6 @@ BrassTable::BrassTable(const char * tablename_, const string & path_,
     LOGCALL_CTOR(DB, "BrassTable", tablename_ | path_ | readonly_ | compress_strategy_ | lazy_);
 }
 
-bool
-BrassTable::really_empty() const
-{
-    if (handle < 0) {
-	if (handle == -2) {
-	    BrassTable::throw_database_closed();
-	}
-	return true;
-    }
-    BrassCursor cur(const_cast<BrassTable*>(this));
-    cur.find_entry(string());
-    return !cur.next();
-}
-
 void
 BrassTable::lazy_alloc_deflate_zstream() const {
     if (usual(deflate_zstream)) {
