@@ -1,7 +1,7 @@
 /** @file chert_values.cc
  * @brief ChertValueManager class
  */
-/* Copyright (C) 2008,2009 Olly Betts
+/* Copyright (C) 2008,2009,2012 Olly Betts
  * Copyright (C) 2008,2009 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or modify
@@ -486,8 +486,13 @@ ChertValueManager::get_all_values(map<Xapian::valueno, string> & values,
 				  Xapian::docid did) const
 {
     Assert(values.empty());
-    if (!termlist_table->is_open())
+    if (!termlist_table->is_open()) {
+	// Either the database has been closed, or else there's no termlist table.
+	// Check if the postlist table is open to determine which is the case.
+	if (!postlist_table->is_open())
+	    ChertTable::throw_database_closed();
 	throw Xapian::FeatureUnavailableError("Database has no termlist");
+    }
     map<Xapian::docid, string>::const_iterator i = slots.find(did);
     string s;
     if (i != slots.end()) {
