@@ -1,7 +1,7 @@
 /* multi_termlist.cc: C++ class definition for multiple database access
  *
  * Copyright 1999,2000,2001 BrightStation PLC
- * Copyright 2002,2003,2004,2005,2006,2007 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,10 +21,11 @@
 
 #include <config.h>
 
-#include "expandweight.h"
-#include "omdebug.h"
 #include "multi_termlist.h"
+
 #include "database.h"
+#include "debuglog.h"
+#include "expandweight.h"
 
 MultiTermList::MultiTermList(TermList * tl_,
 			     const Xapian::Database &db_,
@@ -33,7 +34,7 @@ MultiTermList::MultiTermList(TermList * tl_,
 {
     termfreq_factor = double(db.get_doccount());
     termfreq_factor /= db.internal[db_index]->get_doccount();
-    DEBUGLINE(DB, "Approximation factor for termfreq: " << termfreq_factor);
+    LOGLINE(DB, "Approximation factor for termfreq: " << termfreq_factor);
 }
 
 MultiTermList::~MultiTermList()
@@ -78,6 +79,11 @@ TermList * MultiTermList::next()
     return tl->next();
 }
 
+TermList * MultiTermList::skip_to(const string & term)
+{
+    return tl->skip_to(term);
+}
+
 bool MultiTermList::at_end() const
 {
     return tl->at_end();
