@@ -23,7 +23,7 @@
 #ifndef OM_HGUARD_DOCUMENTTERM_H
 #define OM_HGUARD_DOCUMENTTERM_H
 
-#include "omdebug.h"
+#include "debuglog.h"
 
 #include <string>
 #include <vector>
@@ -43,8 +43,7 @@ class OmDocumentTerm {
     OmDocumentTerm(const string & tname_, Xapian::termcount wdf_)
 	: tname(tname_), wdf(wdf_)
     {
-	DEBUGAPICALL(void, "OmDocumentTerm::OmDocumentTerm",
-		     tname_ << ", " << wdf_);
+	LOGCALL_VOID(DB, "OmDocumentTerm::OmDocumentTerm", tname_ | wdf_);
     }
 
     /** The name of this term.
@@ -73,7 +72,7 @@ class OmDocumentTerm {
      */
     term_positions positions;
 
-    /** Add a position to the posting list.
+    /** Add a position to the position list.
      *
      *  This adds an entry to the list of positions, unless
      *  there is already one for the specified position.
@@ -85,13 +84,14 @@ class OmDocumentTerm {
      */
     void add_position(Xapian::termpos tpos);
 
-    /** Remove an entry from the posting list.
+    /** Remove an entry from the position list.
      *
      *  This removes an entry from the list of positions.
      *
      *  This does not change the value of the wdf.
      *
-     *  @exception Xapian::InvalidArgumentError is thrown if the 
+     *  @exception Xapian::InvalidArgumentError is thrown if the position does
+     *  not occur in the position list.
      */
     void remove_position(Xapian::termpos tpos);
 
@@ -108,7 +108,7 @@ class OmDocumentTerm {
     }
 
     /// Get the wdf
-    Xapian::termcount get_wdf() { return wdf; }
+    Xapian::termcount get_wdf() const { return wdf; }
 
     /// Return a string describing this object.
     string get_description() const;
