@@ -77,15 +77,19 @@ operator<<(PrettyOStream<S> &ps, const Literal & t)
     return ps;
 }
 
-template<class S, class T *>
+template<class S, class T>
 inline PrettyOStream<S> &
 operator<<(PrettyOStream<S> &ps, const T * t)
 {
+    if (!t) {
+	ps.os << "NULL";
+	return ps;
+    }
     ps.os << '&';
     return ps << *t;
 }
 
-template<class S, class T **>
+template<class S, class T>
 inline PrettyOStream<S> &
 operator<<(PrettyOStream<S> &ps, const T ** t)
 {
@@ -93,7 +97,15 @@ operator<<(PrettyOStream<S> &ps, const T ** t)
     return ps;
 }
 
-// FIXME: We probably don't want to inline this, but need to arragne to
+template<class S>
+inline PrettyOStream<S> &
+operator<<(PrettyOStream<S> &ps, const void * t)
+{
+    ps.os << "(void*)" << t;
+    return ps;
+}
+
+// FIXME: We probably don't want to inline this, but need to arrange to
 // put it somewhere sane out-of-line.
 inline void write_ch(std::ostream & os, unsigned char ch)
 {
@@ -207,7 +219,7 @@ operator<<(PrettyOStream<S> &ps, Xapian::termcount * p)
     return ps;
 }
 
-template<class S, typename K, typename V>
+template<class S, typename T>
 inline PrettyOStream<S> &
 operator<<(PrettyOStream<S> &ps, std::list<T> &) {
     ps.os << "std::list&";
@@ -253,6 +265,8 @@ operator<<(PrettyOStream<S> &ps, const std::vector<T> & v) {
 }
 
 namespace Xapian {
+    class ExpandDecider;
+    class MatchDecider;
     class Registry;
     class Weight;
     namespace Internal {
@@ -261,19 +275,41 @@ namespace Xapian {
     }
 }
 
-template<class S>
-inline PrettyOStream<S> &
-operator<<(PrettyOStream<S> &ps, const Xapian::Registry &) {
-    ps.os << "Xapian:Registry";
-    return ps;
+class BrassCursor;
+class BrassDatabase;
+class BrassTable;
+class ChertCursor;
+class ChertDatabase;
+class ChertTable;
+class FlintCursor;
+class FlintDatabase;
+class FlintTable;
+class FlintValueTable;
+class FlintRecordTable;
+
+#define XAPIAN_PRETTY_AS_CLASSNAME(C)\
+template<class S>\
+inline PrettyOStream<S> &\
+operator<<(PrettyOStream<S> &ps, const C &) {\
+    ps.os << #C;\
+    return ps;\
 }
 
-template<class S>
-inline PrettyOStream<S> &
-operator<<(PrettyOStream<S> &ps, const Xapian::Weight &) {
-    ps.os << "Xapian:Weight";
-    return ps;
-}
+XAPIAN_PRETTY_AS_CLASSNAME(Xapian::ExpandDecider)
+XAPIAN_PRETTY_AS_CLASSNAME(Xapian::MatchDecider)
+XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Registry)
+XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Weight)
+XAPIAN_PRETTY_AS_CLASSNAME(BrassCursor);
+XAPIAN_PRETTY_AS_CLASSNAME(BrassDatabase);
+XAPIAN_PRETTY_AS_CLASSNAME(BrassTable);
+XAPIAN_PRETTY_AS_CLASSNAME(ChertCursor);
+XAPIAN_PRETTY_AS_CLASSNAME(ChertDatabase);
+XAPIAN_PRETTY_AS_CLASSNAME(ChertTable);
+XAPIAN_PRETTY_AS_CLASSNAME(FlintCursor);
+XAPIAN_PRETTY_AS_CLASSNAME(FlintDatabase);
+XAPIAN_PRETTY_AS_CLASSNAME(FlintTable);
+XAPIAN_PRETTY_AS_CLASSNAME(FlintValueTable);
+XAPIAN_PRETTY_AS_CLASSNAME(FlintRecordTable);
 
 template<class S>
 inline PrettyOStream<S> &
@@ -305,21 +341,12 @@ operator<<(PrettyOStream<S> &ps, const RemoteConnection &) {
     return ps;
 }
 
-class BrassCursor;
+#include "common/database.h"
 
 template<class S>
 inline PrettyOStream<S> &
-operator<<(PrettyOStream<S> &ps, const BrassCursor *) {
-    ps.os << "BrassCursor*";
-    return ps;
-}
-
-class ChertCursor;
-
-template<class S>
-inline PrettyOStream<S> &
-operator<<(PrettyOStream<S> &ps, const ChertCursor *) {
-    ps.os << "ChertCursor*";
+operator<<(PrettyOStream<S> &ps, const Xapian::Database::Internal *p) {
+    ps.os << "(Database::Internal*)" << (void*)p;
     return ps;
 }
 
