@@ -1,7 +1,7 @@
 /** @file multixorpostlist.cc
  * @brief N-way XOR postlist
  */
-/* Copyright (C) 2007,2009,2010 Olly Betts
+/* Copyright (C) 2007,2009,2010,2012 Olly Betts
  * Copyright (C) 2009 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
@@ -82,6 +82,8 @@ MultiXorPostList::get_termfreq_max() const
 Xapian::doccount
 MultiXorPostList::get_termfreq_est() const
 {
+    if (rare(db_size == 0))
+	RETURN(0);
     // We calculate the estimate assuming independence.  The simplest
     // way to calculate this seems to be a series of (n_kids - 1) pairwise
     // calculations, which gives the same answer regardless of the order.
