@@ -2,7 +2,7 @@
  *
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
- * Copyright 2003,2004,2007 Olly Betts
+ * Copyright 2003,2004,2007,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -51,3 +51,15 @@ SelectPostList::skip_to(Xapian::docid did, Xapian::weight w_min)
     }
     RETURN(NULL);
 }
+
+PostList *
+SelectPostList::check(Xapian::docid did, Xapian::weight w_min, bool &valid)
+{
+    LOGCALL(MATCH, PostList *, "SelectPostList::check", did | w_min | valid);
+    PostList *p = source->check(did, w_min, valid);
+    (void)p;
+    Assert(p == NULL); // AND should never prune
+    if (valid && !source->at_end() && !test_doc())
+	valid = false;
+    RETURN(NULL);
+}
