@@ -750,3 +750,41 @@ DEFINE_TESTCASE(tradweight2, backend) {
     }
     return true;
 }
+
+// Regression test for bug fix in 1.2.9.
+DEFINE_TESTCASE(emptydb1, backend) {
+    Xapian::Database db(get_database(string()));
+    static const Xapian::Query::op ops[] = {
+	Xapian::Query::OP_AND,
+	Xapian::Query::OP_OR,
+	Xapian::Query::OP_AND_NOT,
+	Xapian::Query::OP_XOR,
+	Xapian::Query::OP_AND_MAYBE,
+	Xapian::Query::OP_FILTER,
+	Xapian::Query::OP_NEAR,
+	Xapian::Query::OP_PHRASE,
+	Xapian::Query::OP_ELITE_SET
+    };
+    const Xapian::Query::op * p;
+    for (p = ops; p - ops != sizeof(ops) / sizeof(*ops); ++p) {
+	tout << *p << endl;
+	Xapian::Enquire enquire(db);
+	Xapian::Query query(*p, Xapian::Query("a"), Xapian::Query("b"));
+	enquire.set_query(query);
+	Xapian::MSet mset = enquire.get_mset(0, 10);
+	TEST_EQUAL(mset.get_matches_estimated(), 0);
+	TEST_EQUAL(mset.get_matches_upper_bound(), 0);
+	TEST_EQUAL(mset.get_matches_lower_bound(), 0);
+    }
+    return true;
+}
+
+/// Test error opening non-existent stub databases.
+// Regression test for bug fixed in 1.3.1 and 1.2.11.
+DEFINE_TESTCASE(stubdb7, !backend) {
+    TEST_EXCEPTION(Xapian::DatabaseOpeningError,
+		   Xapian::Auto::open_stub("nosuchdirectory"));
+    TEST_EXCEPTION(Xapian::DatabaseOpeningError,
+		   Xapian::Auto::open_stub("nosuchdirectory", Xapian::DB_OPEN));
+    return true;
+}
